Usage class

Constructors

Usage({required int prompt_tokens, required int completion_tokens, required int total_tokens})
Usage.fromJson(Map<String, dynamic> json)
factory

Properties

completion_tokens ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
prompt_tokens ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total_tokens ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited